/**   @file  oomfill.h
 *   @brief  Library safely (rlimited) consumming RAM to trigger OOMs (only on POSIX systems)
 *
 *   @code{.c}
 *     void myfunction() {
 *         void* ptr = NULL;
 *
 *         // Keep at most 100 bytes available in heap, 4 in stack
 *         oomfill_fill(100,4);
 *         ptr=malloc(2000);
 *         oomfill_free();
 *
 *         // Actual test outside of the constrained code to avoid failure
 *         if (NULL == ptr)
 *             fprintf(stderr,"malloc failed\n");
 *         else
 *             free(ptr);
 *     }
 *
 *     size_t ramlimit;
 *     ramlimit=64*1024*1024;
 *     printf ("Limit memory usage to %uMB : ",ramlimit/1024/1024);
 *     ramlimit = oomfill_config(ramlimit);
 *     printf ("%uB (%uMB)\n",ramlimit,ramlimit/1024/1024);
 *
 *     // not constrained (only by the 64MB ramlimit)
 *     myfunction();
 *
 *     // OOM activation to allow memory eating with a safeguard
 *     oomfill_enable(16*1024*1024);
 *     myfunction();
 *     oomfill_disable();
 *  @endcode
 *
 *  @author  François Cerbelle (Fanfan), francois@cerbelle.net
 *
 *  @internal
 *       Created:  21/06/2024
 *      Revision:  none
 * Last modified:  2024-12-11 10:12
 *      Compiler:  gcc
 *  Organization:  Cerbelle.net
 *     Copyright:  Copyright (c) 2024, François Cerbelle
 *
 *  This source code is released for free distribution under the terms of the
 *  GNU General Public License as published by the Free Software Foundation.
 */

#ifndef __OOMFILL_H__
#define __OOMFILL_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stddef.h>                             /* size_t */

typedef enum { false = (0==1), true = (1==1) } bool;

size_t oomfill_config(const size_t hardlimit);
extern size_t (*oomfill_enable)(const size_t softlimit);
extern size_t (*oomfill_disable)();
extern size_t (*oomfill_fill)(const size_t minHeap, const size_t minStack);
extern void (*oomfill_free)();
extern bool oomfill_enabled();

#endif  /*__OOMFILL_H__ */

/* vim: set tw=80: */
